pecos.qeclib.steane.gates\_tq.transversal\_tq
=============================================

.. automodule:: pecos.qeclib.steane.gates_tq.transversal_tq











   .. rubric:: Classes

   .. autosummary::

      CX
      CY
      CZ
      SZZ
